more muttng -> madmutt
authorPierre Habouzit <madcoder@debian.org>
Tue, 7 Nov 2006 21:25:32 +0000 (22:25 +0100)
committerPierre Habouzit <madcoder@debian.org>
Tue, 7 Nov 2006 21:25:32 +0000 (22:25 +0100)
Signed-off-by: Pierre Habouzit <madcoder@debian.org>
14 files changed:
configure.ac
doc/Makefile.in
doc/madmutt-manual.xsl [moved from doc/muttng-manual.xsl with 85% similarity]
doc/madmutt-tex.xsl [moved from doc/muttng-tex.xsl with 93% similarity]
doc/madmutt.css [moved from doc/muttng.css with 100% similarity]
doc/madmutt.ist [moved from doc/muttng.ist with 100% similarity]
doc/madmutt.sty [moved from doc/muttng.sty with 100% similarity]
init.c
init.h
lib/debug.c
main.c
makedoc.c
muttlib.c
sendlib.c

index 69a09ca..033ef14 100644 (file)
@@ -398,7 +398,7 @@ fi
 AC_MSG_CHECKING(where to put the documentation)
 AC_ARG_WITH(docdir, AC_HELP_STRING([--with-docdir=PATH], [Specify where to put the documentation]),
         [mutt_cv_docdir=$withval],
-        [mutt_cv_docdir="${prefix}/doc/muttng"])
+        [mutt_cv_docdir="${prefix}/doc/madmutt"])
 AC_MSG_RESULT($mutt_cv_docdir)
 
 docdir=$mutt_cv_docdir
index 4b820ec..9359fe0 100644 (file)
@@ -50,9 +50,9 @@ DISTFILES = Makefile.in dotlock.man   \
        instdoc.sh.in                   \
        patch-notes.txt                 \
        smime-notes.txt                 \
-       muttng-manual.xsl               \
-       muttng-tex.xsl                  \
-       muttng.sty                      \
+       madmutt-manual.xsl              \
+       madmutt-tex.xsl                 \
+       madmutt.sty                     \
        html.xsl chunk.xsl
 
 BUILT_DISTFILES = stamp-doc-xml stamp-doc-man stamp-doc-chunked \
@@ -68,19 +68,19 @@ topsrcdir_DOCFILES = COPYRIGHT GPL INSTALL ChangeLog        \
 all: ../makedoc$(EXEEXT)
        $(MAKE) makedoc-all
 
-makedoc-all: muttng.1 muttrc.man manual.html stamp-doc-chunked manual.txt
+makedoc-all: madmutt.1 muttrc.man manual.html stamp-doc-chunked manual.txt
 
 install: all instdoc
        $(top_srcdir)/mkinstalldirs $(DESTDIR)$(mandir)/man1
        $(top_srcdir)/mkinstalldirs $(DESTDIR)$(mandir)/man5
-       ./instdoc muttng.1 $(DESTDIR)$(mandir)/man1/muttng.1
-       ./instdoc $(srcdir)/muttbug.man $(DESTDIR)$(mandir)/man1/muttng-flea.1
-       echo ".so $(mandir)/man1/muttng-flea.1" > $(DESTDIR)$(mandir)/man1/muttngbug.1
-       echo ".so $(mandir)/man1/muttng-flea.1" > $(DESTDIR)$(mandir)/man1/fleang.1
+       ./instdoc madmutt.1 $(DESTDIR)$(mandir)/man1/madmutt.1
+       ./instdoc $(srcdir)/muttbug.man $(DESTDIR)$(mandir)/man1/madmutt-flea.1
+       echo ".so $(mandir)/man1/madmutt-flea.1" > $(DESTDIR)$(mandir)/man1/madmuttbug.1
+       echo ".so $(mandir)/man1/madmutt-flea.1" > $(DESTDIR)$(mandir)/man1/fleang.1
        ./instdoc $(srcdir)/dotlock.man \
-               $(DESTDIR)$(mandir)/man1/muttng_dotlock.1
-       ./instdoc muttrc.man $(DESTDIR)$(mandir)/man5/muttngrc.5
-       ./instdoc $(srcdir)/mbox.man $(DESTDIR)$(mandir)/man5/muttng-mbox.5
+               $(DESTDIR)$(mandir)/man1/madmutt_dotlock.1
+       ./instdoc muttrc.man $(DESTDIR)$(mandir)/man5/madmuttrc.5
+       ./instdoc $(srcdir)/mbox.man $(DESTDIR)$(mandir)/man5/madmutt-mbox.5
        $(top_srcdir)/mkinstalldirs $(DESTDIR)$(docdir)
        for f in $(topsrcdir_DOCFILES) ; do \
                $(INSTALL) -m 644 $(top_srcdir)/$$f $(DESTDIR)$(docdir) ; \
@@ -93,13 +93,13 @@ install: all instdoc
        -cd html; for file in *.html ; do \
                $(INSTALL) -m 644 $$file $(DESTDIR)$(docdir)/html/ || true ;\
        done
-       -$(INSTALL) -m 644 muttng.css $(DESTDIR)$(docdir)/html || true
+       -$(INSTALL) -m 644 madmutt.css $(DESTDIR)$(docdir)/html || true
 
 uninstall:
-       for f in muttng.1 mutt_dotlock.1 fleang.1 muttng-flea.1 muttngbug.1 ; do \
+       for f in madmutt.1 mutt_dotlock.1 fleang.1 madmutt-flea.1 madmuttbug.1 ; do \
          rm -f $(DESTDIR)$(mandir)/man1/$$f ; \
        done
-       for f in muttngrc.5 muttng-mbox.5  ; do \
+       for f in madmuttrc.5 madmutt-mbox.5  ; do \
          rm -f $(DESTDIR)$(mandir)/man5/$$f ; \
        done
        -rm -rf $(DESTDIR)$(docdir)/*
@@ -109,12 +109,12 @@ manual.txt: manual.html
        @HTML2TXT_CMD@
 
 manual.html: $(srcdir)/html.xsl manual.xml
-       -xsltproc --nonet --stringparam html.stylesheet muttng.css -o $@ $^
+       -xsltproc --nonet --stringparam html.stylesheet madmutt.css -o $@ $^
        @HTMLCLEAN_CMD@ $@ || true
 
 manual-chunked stamp-doc-chunked: $(srcdir)/chunk.xsl manual.xml
        test -d html || mkdir html
-       -xsltproc --nonet --stringparam html.stylesheet muttng.css -o html/ $^
+       -xsltproc --nonet --stringparam html.stylesheet madmutt.css -o html/ $^
        touch stamp-doc-chunked
        cd html; for file in *.html ; do \
          @HTMLCLEAN_CMD@ $$file || true ; \
@@ -129,21 +129,21 @@ manual.tex stamp-doc-tex: manual.xml
        fi
        touch stamp-doc-tex
 
-manual-ng.tex: manual.xml muttng-tex.xsl
-       xsltproc -o manual-ng.tex $(srcdir)/muttng-tex.xsl manual-pre.xml
+manual-ng.tex: manual.xml madmutt-tex.xsl
+       xsltproc -o manual-ng.tex $(srcdir)/madmutt-tex.xsl manual-pre.xml
 
-manual-ng.pdf: manual-ng.tex muttng.sty
+manual-ng.pdf: manual-ng.tex madmutt.sty
        (BD=`pwd`; cd $(srcdir); pdflatex -file-line-error -output-directory $$BD $(builddir)/manual-ng.tex)
        (BD=`pwd`; cd $(srcdir); pdflatex -file-line-error -output-directory $$BD $(builddir)/manual-ng.tex)
        touch manual-ng.idx
-       makeindex -s $(srcdir)/muttng.ist -o manual-ng.ind manual-ng.idx
+       makeindex -s $(srcdir)/madmutt.ist -o manual-ng.ind manual-ng.idx
        (BD=`pwd`; cd $(srcdir); pdflatex -file-line-error -output-directory $$BD $(builddir)/manual-ng.tex)
 
-manual-ng.ps: manual-ng.tex muttng.sty
+manual-ng.ps: manual-ng.tex madmutt.sty
        (BD=`pwd`; cd $(srcdir); latex -file-line-error -output-directory $$BD $(builddir)/manual-ng.tex)
        (BD=`pwd`; cd $(srcdir); latex -file-line-error -output-directory $$BD $(builddir)/manual-ng.tex)
        touch manual-ng.idx
-       makeindex -s $(srcdir)/muttng.ist -o manual-ng.ind manual-ng.idx
+       makeindex -s $(srcdir)/madmutt.ist -o manual-ng.ind manual-ng.idx
        (BD=`pwd`; cd $(srcdir); latex -file-line-error -output-directory $$BD $(builddir)/manual-ng.tex)
        dvips -o manual-ng.ps manual-ng.dvi
 
@@ -197,7 +197,7 @@ EDIT=sed -e 's,@sysconfdir\@,$(sysconfdir),g' \
      -e 's,@bindir\@,$(bindir),g' \
      -e 's,@docdir\@,$(docdir),g'
 
-muttng.1: $(srcdir)/mutt.man
+madmutt.1: $(srcdir)/mutt.man
        $(EDIT) $(srcdir)/mutt.man > $@
 
 muttrc.man stamp-doc-man: ../makedoc$(EXEEXT) $(top_srcdir)/init.h muttrc.man.head muttrc.man.tail
@@ -206,9 +206,9 @@ muttrc.man stamp-doc-man: ../makedoc$(EXEEXT) $(top_srcdir)/init.h muttrc.man.he
                > muttrc.man
        touch stamp-doc-man
 
-manual.xml stamp-doc-xml: ../makedoc$(EXEEXT) $(top_srcdir)/init.h muttng-manual.xsl manual.xml.head manual.xml.tail $(top_srcdir)/VERSION.in
+manual.xml stamp-doc-xml: ../makedoc$(EXEEXT) $(top_srcdir)/init.h madmutt-manual.xsl manual.xml.head manual.xml.tail $(top_srcdir)/VERSION.in
        ( sed -e "s/@VERSION\@/`cat $(top_srcdir)/VERSION.in`-rgit/" $(srcdir)/manual.xml.head ;\
          $(MAKEDOC_CPP) $(top_srcdir)/init.h | ../makedoc -s ) |      \
                cat - $(srcdir)/manual.xml.tail > manual-pre.xml
-       -xsltproc --novalid --nonet $(srcdir)/muttng-manual.xsl manual-pre.xml > manual.xml
+       -xsltproc --novalid --nonet $(srcdir)/madmutt-manual.xsl manual-pre.xml > manual.xml
        touch stamp-doc-xml
similarity index 85%
rename from doc/muttng-manual.xsl
rename to doc/madmutt-manual.xsl
index be48b95..2763a03 100644 (file)
@@ -11,7 +11,7 @@
   
 <xsl:stylesheet version="1.0"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
-  xmlns:muttng-doc="http://mutt-ng.berlios.de/doc/#NS"
+  xmlns:madmutt-doc="http://mutt-ng.berlios.de/doc/#NS"
   >
   
   <xsl:output 
@@ -31,7 +31,7 @@
     </xsl:copy>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:man">
+  <xsl:template match="madmutt-doc:man">
     <literal>
       <xsl:choose>
         <xsl:when test="@sect">
     </literal>
   </xsl:template>
  
-  <xsl:template match="muttng-doc:envvar">
+  <xsl:template match="madmutt-doc:envvar">
      <literal><xsl:value-of select="concat('$', @name)"/></literal>
      <indexterm>
        <primary sortas="{@name}"><literal>$<xsl:value-of select="@name"/></literal></primary>
      </indexterm>
   </xsl:template> 
 
-  <xsl:template match="muttng-doc:hook">
+  <xsl:template match="madmutt-doc:hook">
      <literal><link linkend="{concat(@name, '-hook')}"><xsl:value-of select="concat(@name, '-hook')"/></link></literal>
      <indexterm>
        <primary sortas="{@name}-hook"><literal><xsl:value-of select="concat(@name, '-hook')"/></literal></primary>
      </indexterm>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:cmddef">
+  <xsl:template match="madmutt-doc:cmddef">
     <xsl:choose>
       <xsl:when test="@noanchor='1'"/>
       <xsl:otherwise>
      </indexterm>
    </xsl:template>
 
-   <xsl:template match="muttng-doc:cmdref">
+   <xsl:template match="madmutt-doc:cmdref">
      <link linkend="command-{translate(@name,'_','-')}"><literal><xsl:value-of select="@name"/></literal></link>
      <indexterm>
        <primary sortas="{@name}"><literal><xsl:value-of select="@name"/></literal></primary>
      </indexterm>
    </xsl:template>
  
-  <xsl:template match="muttng-doc:pattern">
+  <xsl:template match="madmutt-doc:pattern">
     <literal>~<xsl:value-of select="@name"/></literal>
     <xsl:if test="@full='1'">/<literal>=<xsl:value-of select="@name"/></literal></xsl:if>
      <indexterm>
@@ -87,7 +87,7 @@
      </indexterm>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:funcdef">
+  <xsl:template match="madmutt-doc:funcdef">
      <literal>&lt;<xsl:value-of select="@name"/>&gt;</literal> (default: <xsl:apply-templates/>)
      <anchor id="func-{@name}"/>
      <indexterm>
@@ -95,7 +95,7 @@
      </indexterm>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:funcref">
+  <xsl:template match="madmutt-doc:funcref">
     <!-- currently b0rken as not all defined via :funcdef yet ;-((
     <link linkend="func-{@name}">
     -->
     </indexterm>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:vardef">
+  <xsl:template match="madmutt-doc:vardef">
     <sect1 id="{translate(@name,'_','-')}">
       <title><xsl:value-of select="concat('$',@name)"/></title>
       <indexterm>
     </sect1>
   </xsl:template>
  
-  <xsl:template match="muttng-doc:varref">
+  <xsl:template match="madmutt-doc:varref">
     <link linkend="{@name}"><literal><xsl:value-of select="concat('$',translate(@name,'-','_'))"/></literal></link><indexterm>
       <primary sortas="{@name}"><literal>$<xsl:value-of select="translate(@name,'-','_')"/></literal></primary>
     </indexterm>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:web">
+  <xsl:template match="madmutt-doc:web">
     <ulink url="{@url}"><literal>&lt;<xsl:value-of select="@url"/>&gt;</literal></ulink>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:rfc">
+  <xsl:template match="madmutt-doc:rfc">
     <ulink url="{concat('http://www.faqs.org/rfcs/rfc', @num, '.html')}">RfC <xsl:value-of select="@num"/></ulink>
     <indexterm><primary>RfC</primary><secondary><xsl:value-of select="@num"/></secondary></indexterm>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:lstconf">
+  <xsl:template match="madmutt-doc:lstconf">
     <screen>
       <xsl:apply-templates/>
     </screen>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:lstmail">
+  <xsl:template match="madmutt-doc:lstmail">
     <screen>
       <xsl:apply-templates/>
     </screen>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:lstshell">
+  <xsl:template match="madmutt-doc:lstshell">
     <screen>
       <xsl:apply-templates/>
     </screen>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:key">
+  <xsl:template match="madmutt-doc:key">
     <literal>
       <xsl:if test="@mod">
         <xsl:value-of select="concat(@mod,'-')"/>
     </literal>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:special">
+  <xsl:template match="madmutt-doc:special">
     <xsl:value-of select="@docbook"/>
   </xsl:template>
 
similarity index 93%
rename from doc/muttng-tex.xsl
rename to doc/madmutt-tex.xsl
index 42f057b..f711b37 100644 (file)
 <!--       it contains just enough to convert the       -->
 <!--       mutt-ng manual with some special tags into   -->
 <!--       valid LaTeX code; most of the work is done   -->
-<!--       muttng.sty anyways...                        -->
+<!--       madmutt.sty anyways...                       -->
 
 <xsl:stylesheet version="1.0"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
-  xmlns:muttng-doc="http://mutt-ng.berlios.de/doc/#NS">
+  xmlns:madmutt-doc="http://mutt-ng.berlios.de/doc/#NS">
 
   <xsl:output method="text" indent="no" output-encoding="utf-8"/>
 
@@ -29,7 +29,7 @@
   <xsl:template match="book">
     <xsl:text>
       \documentclass[a4paper]{scrbook}
-      \usepackage{muttng}
+      \usepackage{madmutt}
     </xsl:text>
     <xsl:apply-templates select="bookinfo"/>
     <xsl:apply-templates select="chapter"/>
 
   <!--}}}-->
 
-  <!--{{{ muttng-doc namespace -->
+  <!--{{{ madmutt-doc namespace -->
 
-  <xsl:template match="muttng-doc:man">
+  <xsl:template match="madmutt-doc:man">
     <xsl:text>\man</xsl:text>
      <xsl:if test="@sect">
        <xsl:text>[</xsl:text><xsl:value-of
      <xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:web">
+  <xsl:template match="madmutt-doc:web">
     <xsl:text>\web{</xsl:text><xsl:value-of
       select="@url"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:envvar">
+  <xsl:template match="madmutt-doc:envvar">
     <xsl:text>\envvar{</xsl:text><xsl:value-of select="@name"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:hook">
+  <xsl:template match="madmutt-doc:hook">
     <xsl:text>\hook{</xsl:text><xsl:value-of select="@name"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:cmddef">
+  <xsl:template match="madmutt-doc:cmddef">
     <xsl:text>\cmddef{</xsl:text><xsl:value-of select="@name"/><xsl:text>}{</xsl:text>
     <xsl:apply-templates/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:cmdref">
+  <xsl:template match="madmutt-doc:cmdref">
     <xsl:text>\cmdref{</xsl:text><xsl:value-of select="@name"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:funcref">
+  <xsl:template match="madmutt-doc:funcref">
     <xsl:text>\funcref{</xsl:text><xsl:value-of select="@name"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:funcdef">
+  <xsl:template match="madmutt-doc:funcdef">
     <xsl:text>\funcdef{</xsl:text><xsl:value-of select="@name"/>
     <xsl:text>}{</xsl:text>
-    <xsl:apply-templates select="muttng-doc:key"/><xsl:text>}</xsl:text>
+    <xsl:apply-templates select="madmutt-doc:key"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:varref">
+  <xsl:template match="madmutt-doc:varref">
     <xsl:text>\varref{</xsl:text><xsl:value-of select="translate(@name,'-','_')"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:vardef">
+  <xsl:template match="madmutt-doc:vardef">
     <xsl:text>\vardef{</xsl:text>
     <xsl:value-of select="@name"/>
     <xsl:text>}
     <xsl:apply-templates/>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:rfc">
+  <xsl:template match="madmutt-doc:rfc">
     <xsl:text>\rfc{</xsl:text><xsl:value-of select="@num"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:lstconf">
+  <xsl:template match="madmutt-doc:lstconf">
     <xsl:text>\begin{verbatim}</xsl:text>
     <xsl:value-of select="text()"/><xsl:text>\end{verbatim}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:lstmail">
+  <xsl:template match="madmutt-doc:lstmail">
     <xsl:text>\begin{verbatim}</xsl:text>
     <xsl:value-of select="text()"/><xsl:text>\end{verbatim}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:lstshell">
+  <xsl:template match="madmutt-doc:lstshell">
     <xsl:text>\begin{verbatim}</xsl:text>
     <xsl:value-of select="text()"/><xsl:text>\end{verbatim}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:pattern">
+  <xsl:template match="madmutt-doc:pattern">
     <xsl:text>\pat</xsl:text>
     <xsl:if test="@full='1'">
       <xsl:text>[1]</xsl:text>
       select="@name"/><xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:key">
+  <xsl:template match="madmutt-doc:key">
     <xsl:text>\key{</xsl:text>
     <xsl:if test="@mod">
       <xsl:value-of select="@mod"/><xsl:text>-</xsl:text>
     <xsl:text>}</xsl:text>
   </xsl:template>
 
-  <xsl:template match="muttng-doc:special">
+  <xsl:template match="madmutt-doc:special">
     <xsl:value-of select="@latex"/>
   </xsl:template>
 
similarity index 100%
rename from doc/muttng.css
rename to doc/madmutt.css
similarity index 100%
rename from doc/muttng.ist
rename to doc/madmutt.ist
similarity index 100%
rename from doc/muttng.sty
rename to doc/madmutt.sty
diff --git a/main.c b/main.c
index 9cf0437..30148f0 100644 (file)
--- a/main.c
+++ b/main.c
@@ -93,9 +93,9 @@ To report a bug, please use the fleang(1) utility.\n");
 
 static const char *Notice = N_("\
 Copyright (C) 1996-2002 Michael R. Elkins and others.\n\
-Mutt-ng comes with ABSOLUTELY NO WARRANTY; for details type `muttng -vv'.\n\
+Mutt-ng comes with ABSOLUTELY NO WARRANTY; for details type `madmutt -vv'.\n\
 Mutt is free software, and you are welcome to redistribute it\n\
-under certain conditions; type `muttng -vv' for details.\n");
+under certain conditions; type `madmutt -vv' for details.\n");
 
 static const char *Copyright_Mutt = N_("\
 Copyright (C) 1996-2004 Michael R. Elkins <me@mutt.org>\n\
@@ -146,16 +146,16 @@ static void mutt_usage (void)
   puts (mutt_make_version (1));
 
   puts
-    _("usage: muttng [ -nRyzZ ] [ -e <cmd> ] [ -F <file> ] [ -m <type> ] [ -f <file> ]\n\
-       muttng [ -nR ] [ -e <cmd> ] [ -F <file> ] -Q <query> [ -Q <query> ] [...]\n\
-       muttng [ -nR ] [ -e <cmd> ] [ -F <file> ] -A <alias> [ -A <alias> ] [...]\n\
-       muttng [ -nR ] [ -e <cmd> ] [ -F <file> ] -t");
+    _("usage: madmutt [ -nRyzZ ] [ -e <cmd> ] [ -F <file> ] [ -m <type> ] [ -f <file> ]\n\
+       madmutt [ -nR ] [ -e <cmd> ] [ -F <file> ] -Q <query> [ -Q <query> ] [...]\n\
+       madmutt [ -nR ] [ -e <cmd> ] [ -F <file> ] -A <alias> [ -A <alias> ] [...]\n\
+       madmutt [ -nR ] [ -e <cmd> ] [ -F <file> ] -t");
   puts
     _("\
-       muttng [ -nR ] [ -e <cmd> ] [ -F <file> ] -T\n\
-       muttng [ -nx ] [ -e <cmd> ] [ -a <file> ] [ -F <file> ] [ -H <file> ] [ -i <file> ] [ -s <subj> ] [ -b <addr> ] [ -c <addr> ] <addr> [ ... ]\n\
-       muttng [ -n ] [ -e <cmd> ] [ -F <file> ] -p\n\
-       muttng -v[v]\n\
+       madmutt [ -nR ] [ -e <cmd> ] [ -F <file> ] -T\n\
+       madmutt [ -nx ] [ -e <cmd> ] [ -a <file> ] [ -F <file> ] [ -H <file> ] [ -i <file> ] [ -s <subj> ] [ -b <addr> ] [ -c <addr> ] <addr> [ ... ]\n\
+       madmutt [ -n ] [ -e <cmd> ] [ -F <file> ] -p\n\
+       madmutt -v[v]\n\
 \n\
 options:\n\
   -A <alias>\texpand the given alias\n\
@@ -163,7 +163,7 @@ options:\n\
   -b <address>\tspecify a blind carbon-copy (BCC) address\n\
   -c <address>\tspecify a carbon-copy (CC) address");
 #if DEBUG
-  puts _("  -d <level>\tlog debugging output to ~/.muttngdebug0");
+  puts _("  -d <level>\tlog debugging output to ~/.madmuttdebug0");
 #endif
   puts _("\
   -e <command>\tspecify a command to be executed after initialization\n\
index 6910e54..df72d5d 100644 (file)
--- a/makedoc.c
+++ b/makedoc.c
@@ -738,7 +738,7 @@ static void print_confline (const char *varname, int type, const char *val)
     /* SGML based manual */
   case F_SGML:
     {
-      add_s ("\n<muttng-doc:vardef name=\"");
+      add_s ("\n<madmutt-doc:vardef name=\"");
       sgml_fputs (varname);
       add_s ("\">\n<para>Type: <literal>");
       add_s (type2human (type));
@@ -1164,7 +1164,7 @@ static int print_it (int special, char *str, int docstat)
         }
       case SP_END_SECT:
         {
-          add_s ("</muttng-doc:vardef>\n");
+          add_s ("</madmutt-doc:vardef>\n");
           break;
         }
       case SP_STR:
index a9d58e9..f4654df 100644 (file)
--- a/muttlib.c
+++ b/muttlib.c
@@ -590,7 +590,7 @@ void mutt_merge_envelopes(ENVELOPE* base, ENVELOPE** extra)
 void _mutt_mktemp (char *s, const char *src, int line)
 {
 
-  snprintf (s, _POSIX_PATH_MAX, "%s/muttng-%s-%d-%d-%d-%x%x", NONULL (Tempdir),
+  snprintf (s, _POSIX_PATH_MAX, "%s/madmutt-%s-%d-%d-%d-%x%x", NONULL (Tempdir),
             NONULL (Hostname), (int) getuid (), (int) getpid (), Counter++, 
             (unsigned int) rand(), (unsigned int) rand());
   debug_print (1, ("%s:%d: mutt_mktemp returns \"%s\".\n", src, line, s));
index 02d0ee0..57e4de8 100644 (file)
--- a/sendlib.c
+++ b/sendlib.c
@@ -887,7 +887,7 @@ int mutt_lookup_mime_type (BODY * att, const char *path)
       snprintf (buf, sizeof (buf), "%s/.mime.types", NONULL (Homedir));
       break;
     case 1:
-      m_strcpy(buf, sizeof(buf), SYSCONFDIR "/muttng-mime.types");
+      m_strcpy(buf, sizeof(buf), SYSCONFDIR "/madmutt-mime.types");
       break;
     case 2:
       m_strcpy(buf, sizeof(buf), PKGDATADIR "/mime.types");
diff --git a/init.c b/init.c
index f86e465..7de40b8 100644 (file)
--- a/init.c
+++ b/init.c
@@ -263,15 +263,15 @@ static void sys_to_string (char* dst, size_t dstlen,
   char *val = NULL, *t = NULL;
   int clean = 0;
 
-  /* get some $muttng_ values dynamically */
-  if (ascii_strcmp ("muttng_pwd", option->option) == 0) {
+  /* get some $madmutt_ values dynamically */
+  if (ascii_strcmp ("madmutt_pwd", option->option) == 0) {
     val = p_new(char, _POSIX_PATH_MAX);
     val = getcwd (val, _POSIX_PATH_MAX-1);
     clean = 1;
-  } else if (ascii_strcmp ("muttng_folder_path", option->option) == 0 &&
+  } else if (ascii_strcmp ("madmutt_folder_path", option->option) == 0 &&
              CurrentFolder && *CurrentFolder) {
     val = CurrentFolder;
-  } else if (ascii_strcmp ("muttng_folder_name", option->option) == 0 &&
+  } else if (ascii_strcmp ("madmutt_folder_name", option->option) == 0 &&
              CurrentFolder && *CurrentFolder) {
 
     ssize_t Maildirlength = m_strlen(Maildir);
@@ -2006,7 +2006,7 @@ static int parse_set (BUFFER * tmp, BUFFER * s, unsigned long data,
         break;
       }
 
/* the $muttng_ variables are read-only */
       if (!FuncTable[DTYPE (option->type)].opt_from_string) {
         snprintf (err->data, err->dsize, _("$%s is read-only"),
                   option->option);
@@ -2762,18 +2762,18 @@ void mutt_init (int skip_sys_rc, LIST * commands)
 
   if (!Muttrc) {
 #if 0
-    snprintf (buffer, sizeof(buffer), "%s/.muttngrc-%s", NONULL (Homedir),
+    snprintf (buffer, sizeof(buffer), "%s/.madmuttrc-%s", NONULL (Homedir),
               MUTT_VERSION);
     if (access (buffer, F_OK) == -1)
 #endif
-      snprintf (buffer, sizeof(buffer), "%s/.muttngrc", NONULL (Homedir));
+      snprintf (buffer, sizeof(buffer), "%s/.madmuttrc", NONULL (Homedir));
     if (access (buffer, F_OK) == -1)
 #if 0
-      snprintf (buffer, sizeof(buffer), "%s/.muttng/muttngrc-%s",
+      snprintf (buffer, sizeof(buffer), "%s/.madmutt/madmuttrc-%s",
                 NONULL (Homedir), MUTT_VERSION);
     if (access (buffer, F_OK) == -1)
 #endif
-      snprintf (buffer, sizeof(buffer), "%s/.muttng/muttngrc",
+      snprintf (buffer, sizeof(buffer), "%s/.madmutt/madmuttrc",
                 NONULL (Homedir));
 
     default_rc = 1;
@@ -2006,7 +2006,7 @@ static int parse_set (BUFFER * tmp, BUFFER * s, unsigned long data,
       }
 
-      /* the $muttng_ variables are read-only */
+      /* the $madmutt_ variables are read-only */
       if (!FuncTable[DTYPE (option->type)].opt_from_string) {
         snprintf (err->data, err->dsize, _("$%s is read-only"),
diff --git a/init.h b/init.h
index ac29376..65d5e1f 100644 (file)
--- a/init.h
+++ b/init.h
@@ -35,7 +35,7 @@
 #define DT_SYN          9       /* synonym for another variable */
 #define DT_ADDR         10      /* e-mail address */
 #define DT_USER         11      /* user defined via $user_ */
-#define DT_SYS          12      /* pre-defined via $muttng_ */
+#define DT_SYS          12      /* pre-defined via $madmutt_ */
 
 #define DTYPE(x) ((x) & DT_MASK)
 
@@ -146,7 +146,7 @@ struct option_t MuttVars[] = {
    ** check only happens after the \fIfirst\fP edit of the file).  When set
    ** to \fIno\fP, composition will never be aborted.
    */
-  {"alias_file", DT_PATH, R_NONE, UL &AliasFile, "~/.muttngrc"},
+  {"alias_file", DT_PATH, R_NONE, UL &AliasFile, "~/.madmuttrc"},
   /*
    ** .pp
    ** The default file in which to save aliases created by the 
@@ -280,7 +280,7 @@ struct option_t MuttVars[] = {
   {"attach_remind_regexp", DT_RX, R_NONE, UL &AttachRemindRegexp, "attach"},
   /*
    ** .pp
** If this variable is non-empty, muttng will scan a message's contents
    ** before sending for this regular expression. If it is found, it will
    ** ask for what to do depending on the setting of $$abort_noattach.
    ** .pp
@@ -478,7 +478,7 @@ struct option_t MuttVars[] = {
    ** If it is \fIset\fP and Mutt-ng was build with gpgme support, the gpgme code for
    ** S/MIME and PGP will be used instead of the classic code.
    ** .pp
** \fBNote\fP: You need to use this option in your \fT.muttngrc\fP configuration
    ** file as it won't have any effect when used interactively.
    */
 
@@ -525,7 +525,7 @@ struct option_t MuttVars[] = {
    ** \fT-d\fP command line option.
    **
    ** .pp
** Currently, this number must be >= 0 and <= 5 and muttng
    ** must be started with \fT-d\fP to enable debugging at all;
    ** enabling at runtime is not possible.
    */
@@ -586,13 +586,13 @@ struct option_t MuttVars[] = {
    ** filtered message is read from the standard output.
    */
 #if defined(USE_DOTLOCK)
-  {"dotlock_program", DT_PATH, R_NONE, UL &MuttDotlock, "$muttng_bindir/muttng_dotlock"},
+  {"dotlock_program", DT_PATH, R_NONE, UL &MuttDotlock, "$madmutt_bindir/muttng_dotlock"},
   /*
    ** .pp
    ** Availability: Dotlock
    **
    ** .pp
-   ** Contains the path of the \fTmuttng_dotlock(1)\fP binary to be used by
+   ** Contains the path of the \fTmadmutt_dotlock(1)\fP binary to be used by
    ** Mutt-ng.
    */
 #endif
@@ -1001,7 +1001,7 @@ struct option_t MuttVars[] = {
    ** mailing list when this option is set, use the \fIlist-reply\fP
    ** function; \fIgroup-reply\fP will reply to both the sender and the
    ** list.
** Remember: This option works only for mailing lists which are explicitly set in your muttngrc
    ** configuration file.
    */
   {"imap_authenticators", DT_STR, R_NONE, UL &ImapAuthenticators, "" },
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** This specifies the folder into which read mail in your ``$$spoolfile''
    ** folder will be appended.
    */
-  {"muttng_version", DT_SYS, R_NONE, 0, VERSION },
+  {"madmutt_version", DT_SYS, R_NONE, 0, VERSION },
   /*
    ** .pp
** \fIThis is a read-only system property and specifies muttng's
    ** version string.\fP
    */
-  {"muttng_revision", DT_SYS, R_NONE, 0, MUTT_REVISION },
+  {"madmutt_revision", DT_SYS, R_NONE, 0, MUTT_REVISION },
   /*
    ** .pp
** \fIThis is a read-only system property and specifies muttng's
    ** subversion revision string.\fP
    */
-  {"muttng_sysconfdir", DT_SYS, R_NONE, 0, SYSCONFDIR },
+  {"madmutt_sysconfdir", DT_SYS, R_NONE, 0, SYSCONFDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng system-wide configuration.\fP
    */
-  {"muttng_bindir", DT_SYS, R_NONE, 0, BINDIR },
+  {"madmutt_bindir", DT_SYS, R_NONE, 0, BINDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng binary.\fP
    */
-  {"muttng_docdir", DT_SYS, R_NONE, 0, PKGDOCDIR },
+  {"madmutt_docdir", DT_SYS, R_NONE, 0, PKGDOCDIR },
   /*
    ** .pp
    ** \fIThis is a read-only system property and specifies the
** directory containing the muttng documentation.\fP
    */
 #ifdef USE_HCACHE
 #if HAVE_QDBM
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "qdbm" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "qdbm" },
 #elif HAVE_GDBM
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "gdbm" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "gdbm" },
 #elif HAVE_DB4
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "db4" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "db4" },
 #else
-  {"muttng_hcache_backend", DT_SYS, R_NONE, 0, "unknown" },
+  {"madmutt_hcache_backend", DT_SYS, R_NONE, 0, "unknown" },
 #endif
   /*
    ** .pp
@@ -1459,14 +1459,14 @@ struct option_t MuttVars[] = {
    ** header chaching's database backend.\fP
    */
 #endif
-  {"muttng_folder_path", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_folder_path", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
    ** specifies the full path or URI of the folder currently
    ** open (if any).\fP
    */
-  {"muttng_folder_name", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_folder_name", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
@@ -1476,7 +1476,7 @@ struct option_t MuttVars[] = {
    ** For detection, $$$folder is first taken into account
    ** and simply stripped to form the result when a match is found. For
    ** example, with $$$folder being \fTimap://host\fP and the folder is
** \fTimap://host/INBOX/foo\fP, $$$muttng_folder_name will be just
    ** \fTINBOX/foo\fP.)
    ** .pp
    ** Second, if the initial portion of a name is not $$$folder,
@@ -1485,11 +1485,11 @@ struct option_t MuttVars[] = {
    ** Third and last, the result will be just the name if neither
    ** $$$folder nor a ``/'' were found in the name.
    */
-  {"muttng_pwd", DT_SYS, R_NONE, 0, "" },
+  {"madmutt_pwd", DT_SYS, R_NONE, 0, "" },
   /*
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
** specifies the current working directory of the muttng
    ** binary.\fP
    */
   {"operating_system", DT_STR, R_NONE, UL &OperatingSystem, "" },
@@ -1758,7 +1758,7 @@ struct option_t MuttVars[] = {
    ** deeper threads to fit on the screen.
    */
 #ifdef USE_NNTP
-  {"nntp_cache_dir", DT_PATH, R_NONE, UL &NewsCacheDir, "~/.muttng"},
+  {"nntp_cache_dir", DT_PATH, R_NONE, UL &NewsCacheDir, "~/.madmutt"},
   /*
    ** .pp
    ** Availability: NNTP
@@ -2592,7 +2592,7 @@ struct option_t MuttVars[] = {
    ** certificate that is signed with one of these CA certificates are 
    ** also automatically accepted.
    ** .pp
-   ** Example: \fTset certificate_file=~/.muttng/certificates\fP
+   ** Example: \fTset certificate_file=~/.madmutt/certificates\fP
    */
 # if defined(_MAKEDOC) || !defined (USE_GNUTLS)
   {"ssl_usesystemcerts", DT_BOOL, R_NONE, OPTSSLSYSTEMCERTS, "yes" },
@@ -3510,7 +3510,7 @@ struct option_t MuttVars[] = {
    ** .pp
    ** When \fIunset\fP, Mutt-ng won't stop when the user presses the terminal's
    ** \fIsusp\fP key, usually \fTCTRL+Z\fP. This is useful if you run Mutt-ng
** inside an xterm using a command like ``\fTxterm -e muttng\fP.''
    */
   {"text_flowed", DT_BOOL, R_NONE, OPTTEXTFLOWED, "no" },
   /*
index 523d7c6..6034ef9 100644 (file)
@@ -41,8 +41,8 @@ void debug_start (const char* basedir) {
     return;
   /* rotate the old debug logs */
   for (i = 3; i >= 0; i--) {
-    snprintf (buf, sizeof (buf), "%s/.muttngdebug%d", NONULL (basedir), i);
-    snprintf (buf2, sizeof (buf2), "%s/.muttngdebug%d", NONULL (basedir), i + 1);
+    snprintf (buf, sizeof (buf), "%s/.madmuttdebug%d", NONULL (basedir), i);
+    snprintf (buf2, sizeof (buf2), "%s/.madmuttdebug%d", NONULL (basedir), i + 1);
     rename (buf, buf2);
   }
   if ((DebugFile = safe_fopen (buf, "w")) != NULL) {
@@ -280,7 +280,7 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** If this variable is non-empty, muttng will scan a message's contents
+   ** If this variable is non-empty, madmutt will scan a message's contents
    ** before sending for this regular expression. If it is found, it will
    ** ask for what to do depending on the setting of $$abort_noattach.
@@ -478,7 +478,7 @@ struct option_t MuttVars[] = {
    ** S/MIME and PGP will be used instead of the classic code.
    ** .pp
-   ** \fBNote\fP: You need to use this option in your \fT.muttngrc\fP configuration
+   ** \fBNote\fP: You need to use this option in your \fT.madmuttrc\fP configuration
    ** file as it won't have any effect when used interactively.
    */
@@ -525,7 +525,7 @@ struct option_t MuttVars[] = {
    **
    ** .pp
-   ** Currently, this number must be >= 0 and <= 5 and muttng
+   ** Currently, this number must be >= 0 and <= 5 and madmutt
    ** must be started with \fT-d\fP to enable debugging at all;
    ** enabling at runtime is not possible.
@@ -1001,7 +1001,7 @@ struct option_t MuttVars[] = {
    ** function; \fIgroup-reply\fP will reply to both the sender and the
    ** list.
-   ** Remember: This option works only for mailing lists which are explicitly set in your muttngrc
+   ** Remember: This option works only for mailing lists which are explicitly set in your madmuttrc
    ** configuration file.
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** \fIThis is a read-only system property and specifies muttng's
+   ** \fIThis is a read-only system property and specifies madmutt's
    ** version string.\fP
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
-   ** \fIThis is a read-only system property and specifies muttng's
+   ** \fIThis is a read-only system property and specifies madmutt's
    ** subversion revision string.\fP
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng system-wide configuration.\fP
+   ** directory containing the madmutt system-wide configuration.\fP
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng binary.\fP
+   ** directory containing the madmutt binary.\fP
    */
@@ -1413,45 +1413,45 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and specifies the
-   ** directory containing the muttng documentation.\fP
+   ** directory containing the madmutt documentation.\fP
    */
 #ifdef USE_HCACHE
@@ -1476,7 +1476,7 @@ struct option_t MuttVars[] = {
    ** and simply stripped to form the result when a match is found. For
    ** example, with $$$folder being \fTimap://host\fP and the folder is
-   ** \fTimap://host/INBOX/foo\fP, $$$muttng_folder_name will be just
+   ** \fTimap://host/INBOX/foo\fP, $$$madmutt_folder_name will be just
    ** \fTINBOX/foo\fP.)
    ** .pp
@@ -1485,11 +1485,11 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fIThis is a read-only system property and, at runtime,
-   ** specifies the current working directory of the muttng
+   ** specifies the current working directory of the madmutt
    ** binary.\fP
    */
@@ -3510,7 +3510,7 @@ struct option_t MuttVars[] = {
    ** When \fIunset\fP, Mutt-ng won't stop when the user presses the terminal's
    ** \fIsusp\fP key, usually \fTCTRL+Z\fP. This is useful if you run Mutt-ng
-   ** inside an xterm using a command like ``\fTxterm -e muttng\fP.''
+   ** inside an xterm using a command like ``\fTxterm -e madmutt\fP.''
    */
   {"text_flowed", DT_BOOL, R_NONE, OPTTEXTFLOWED, "no" },